pub fn format_diagnostic(diag: &Diagnostic) -> StringExpand description
Format a Diagnostic for stderr output, respecting the current error format.
pub fn format_diagnostic(diag: &Diagnostic) -> StringFormat a Diagnostic for stderr output, respecting the current error format.