Module builder

Module builder 

Functions

build_graph
Build the lineage graph from discovered files. If cache_dir is provided, it is used as the cache directory; otherwise the cache is stored under <project_dir>/.dlin_cache/. If no_cache is true, the extraction cache is completely disabled. If refresh_cache is true, the existing cache is ignored but new results are written to disk.