build_graph

Function build_graph 

pub fn build_graph(
    project_dir: &Path,
    files: &DiscoveredFiles,
    cache_dir: Option<&Path>,
    no_cache: bool,
    refresh_cache: bool,
    vars: &HashMap<String, Value>,
) -> Result<LineageGraph>
Build the lineage graph from discovered files. If cache_dir is provided, it is used as the cache directory; otherwise the cache is stored under <project_dir>/.dlin_cache/. If no_cache is true, the extraction cache is completely disabled. If refresh_cache is true, the existing cache is ignored but new results are written to disk.