read_stdin_lines

Function read_stdin_lines 

pub fn read_stdin_lines() -> Vec<String>
Read lines from stdin if data is being piped or redirected from a file. Returns an empty Vec if stdin is a terminal (interactive mode) or if stdin is not a pipe/regular file (e.g. /dev/null in CI or AI agent environments).