resolve_stdin_inputs

Function resolve_stdin_inputs 

pub fn resolve_stdin_inputs(
    lines: &[String],
    graph: &LineageGraph,
    resolved_paths: &ResolvedPaths,
    project_dir: &Path,
    cwd: &Path,
) -> Vec<String>
Process input lines and resolve them to model/source names suitable for use as focus models in filter_graph.

cwd is the working directory used to resolve relative file paths (e.g. paths from git diff --name-only). This may differ from project_dir when the dbt project lives in a subdirectory of the git repository.