Structs
- Column
Definition - Exposure
Definition - Exposure
Owner - Measure
Definition - Metric
Definition - A metric definition (dbt Semantic Layer)
- Model
Config - Model
Definition - Saved
Query Definition - A saved query definition (dbt Semantic Layer)
- Saved
Query Query Params - Schema
File - Top-level schema YAML file (can contain sources, models, snapshots, exposures, semantic_models, metrics, saved_queries)
- Semantic
Model Definition - A semantic model definition (dbt Semantic Layer)
- Snapshot
Definition - YAML-only snapshot definition (dbt v1.9+).
When no
.sqlfile exists for the snapshot, the graph node is built from this. - Source
Definition - Source
Table - Version
Spec - A single entry in the
versions:list of a model definition.
Enums
- Test
Definition - Tests can be either a string or a map.
Complex variants are deserialized into
serde_json::Valuebecause serde-saphyr has no intermediate Value type. This is safe for dbt schema files which use JSON-compatible YAML.
Functions
- parse_
schema_ file - Parse a schema YAML file