pub enum TestDefinition {
Simple(String),
Complex(Value),
}Expand description
Tests can be either a string or a map.
Complex variants are deserialized into serde_json::Value because serde-saphyr
has no intermediate Value type. This is safe for dbt schema files which use
JSON-compatible YAML.
Variants
Implementations