Functions
- build_
graph - Build the lineage graph from discovered files.
If
cache_diris provided, it is used as the cache directory; otherwise the cache is stored under<project_dir>/.dlin_cache/. Ifno_cacheis true, the extraction cache is completely disabled. Ifrefresh_cacheis true, the existing cache is ignored but new results are written to disk.