Check whether any of the given input strings look like file paths rather
than bare model names. Used to decide whether to load DbtProject for
path resolution.
Read lines from stdin if data is being piped or redirected from a file.
Returns an empty Vec if stdin is a terminal (interactive mode) or if
stdin is not a pipe/regular file (e.g. /dev/null in CI or AI agent
environments).